<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\trace.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.trace`




**Global Variables**
---------------
- **start_time**

---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\trace.py#L7"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `out`

```python
out(*args)
```

The print function used by the trace decorator. 

Overwrite this function to change the output behavior, eg to use logging instead of print. 


---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\trace.py#L16"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `trace`

```python
trace(func)
```

A decorator that logs registration, execution, and completion times of a function. 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
